# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/featuregroup/v1/featuregroup.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIgithub.com/metaprov/modelaapi/services/featuregroup/v1/featuregroup.proto\x12\x36github.com.metaprov.modelaapi.services.featuregroup.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x81\x02\n\x17ListFeatureGroupRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12k\n\x06labels\x18\x02 \x03(\x0b\x32[.github.com.metaprov.modelaapi.services.featuregroup.v1.ListFeatureGroupRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x01\n\x18ListFeatureGroupResponse\x12]\n\rfeaturegroups\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroupList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"u\n\x19\x43reateFeatureGroupRequest\x12X\n\x0c\x66\x65\x61turegroup\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\"\x1c\n\x1a\x43reateFeatureGroupResponse\"\xa5\x01\n\x19UpdateFeatureGroupRequest\x12X\n\x0c\x66\x65\x61turegroup\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1c\n\x1aUpdateFeatureGroupResponse\"9\n\x16GetFeatureGroupRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x81\x01\n\x17GetFeatureGroupResponse\x12X\n\x0c\x66\x65\x61turegroup\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"<\n\x19\x44\x65leteFeatureGroupRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1a\x44\x65leteFeatureGroupResponse\"\x1b\n\x19PauseFeatureGroupResponse\";\n\x18PauseFeatureGroupRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1aResumeFeatureGroupResponse\"<\n\x19ResumeFeatureGroupRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\x9c\r\n\x13\x46\x65\x61tureGroupService\x12\xdd\x01\n\x11ListFeatureGroups\x12O.github.com.metaprov.modelaapi.services.featuregroup.v1.ListFeatureGroupRequest\x1aP.github.com.metaprov.modelaapi.services.featuregroup.v1.ListFeatureGroupResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/featuregroups/{namespace}\x12\xd9\x01\n\x12\x43reateFeatureGroup\x12Q.github.com.metaprov.modelaapi.services.featuregroup.v1.CreateFeatureGroupRequest\x1aR.github.com.metaprov.modelaapi.services.featuregroup.v1.CreateFeatureGroupResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/featuregroups:\x01*\x12\xe0\x01\n\x0fGetFeatureGroup\x12N.github.com.metaprov.modelaapi.services.featuregroup.v1.GetFeatureGroupRequest\x1aO.github.com.metaprov.modelaapi.services.featuregroup.v1.GetFeatureGroupResponse\",\x82\xd3\xe4\x93\x02&\x12$/v1/featuregroups/{namespace}/{name}\x12\x98\x02\n\x12UpdateFeatureGroup\x12Q.github.com.metaprov.modelaapi.services.featuregroup.v1.UpdateFeatureGroupRequest\x1aR.github.com.metaprov.modelaapi.services.featuregroup.v1.UpdateFeatureGroupResponse\"[\x82\xd3\xe4\x93\x02U\x1aP/v1/featuregroups/{featuregroup.metadata.namespace}/{featuregroup.metadata.name}:\x01*\x12\xe9\x01\n\x12\x44\x65leteFeatureGroup\x12Q.github.com.metaprov.modelaapi.services.featuregroup.v1.DeleteFeatureGroupRequest\x1aR.github.com.metaprov.modelaapi.services.featuregroup.v1.DeleteFeatureGroupResponse\",\x82\xd3\xe4\x93\x02&*$/v1/featuregroups/{namespace}/{name}\x12\xec\x01\n\x11PauseFeatureGroup\x12P.github.com.metaprov.modelaapi.services.featuregroup.v1.PauseFeatureGroupRequest\x1aQ.github.com.metaprov.modelaapi.services.featuregroup.v1.PauseFeatureGroupResponse\"2\x82\xd3\xe4\x93\x02,\"*/v1/featuregroups/{namespace}/{name}:pause\x12\xef\x01\n\x12ResumeFeatureGroup\x12Q.github.com.metaprov.modelaapi.services.featuregroup.v1.ResumeFeatureGroupRequest\x1aR.github.com.metaprov.modelaapi.services.featuregroup.v1.ResumeFeatureGroupResponse\"2\x82\xd3\xe4\x93\x02,\"*/v1/featuregroups/{namespace}/{name}:pauseB8Z6github.com/metaprov/modelaapi/services/featuregroup/v1b\x06proto3')



_LISTFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['ListFeatureGroupRequest']
_LISTFEATUREGROUPREQUEST_LABELSENTRY = _LISTFEATUREGROUPREQUEST.nested_types_by_name['LabelsEntry']
_LISTFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['ListFeatureGroupResponse']
_CREATEFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreateFeatureGroupRequest']
_CREATEFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['CreateFeatureGroupResponse']
_UPDATEFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeatureGroupRequest']
_UPDATEFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeatureGroupResponse']
_GETFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureGroupRequest']
_GETFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureGroupResponse']
_DELETEFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureGroupRequest']
_DELETEFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeatureGroupResponse']
_PAUSEFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['PauseFeatureGroupResponse']
_PAUSEFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['PauseFeatureGroupRequest']
_RESUMEFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['ResumeFeatureGroupResponse']
_RESUMEFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['ResumeFeatureGroupRequest']
ListFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('ListFeatureGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATUREGROUPREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.ListFeatureGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.ListFeatureGroupRequest)
  })
_sym_db.RegisterMessage(ListFeatureGroupRequest)
_sym_db.RegisterMessage(ListFeatureGroupRequest.LabelsEntry)

ListFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('ListFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.ListFeatureGroupResponse)
  })
_sym_db.RegisterMessage(ListFeatureGroupResponse)

CreateFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.CreateFeatureGroupRequest)
  })
_sym_db.RegisterMessage(CreateFeatureGroupRequest)

CreateFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('CreateFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.CreateFeatureGroupResponse)
  })
_sym_db.RegisterMessage(CreateFeatureGroupResponse)

UpdateFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.UpdateFeatureGroupRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureGroupRequest)

UpdateFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.UpdateFeatureGroupResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureGroupResponse)

GetFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('GetFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.GetFeatureGroupRequest)
  })
_sym_db.RegisterMessage(GetFeatureGroupRequest)

GetFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('GetFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.GetFeatureGroupResponse)
  })
_sym_db.RegisterMessage(GetFeatureGroupResponse)

DeleteFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.DeleteFeatureGroupRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureGroupRequest)

DeleteFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('DeleteFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.DeleteFeatureGroupResponse)
  })
_sym_db.RegisterMessage(DeleteFeatureGroupResponse)

PauseFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('PauseFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.PauseFeatureGroupResponse)
  })
_sym_db.RegisterMessage(PauseFeatureGroupResponse)

PauseFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('PauseFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.PauseFeatureGroupRequest)
  })
_sym_db.RegisterMessage(PauseFeatureGroupRequest)

ResumeFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('ResumeFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.ResumeFeatureGroupResponse)
  })
_sym_db.RegisterMessage(ResumeFeatureGroupResponse)

ResumeFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('ResumeFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.ResumeFeatureGroupRequest)
  })
_sym_db.RegisterMessage(ResumeFeatureGroupRequest)

_FEATUREGROUPSERVICE = DESCRIPTOR.services_by_name['FeatureGroupService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/metaprov/modelaapi/services/featuregroup/v1'
  _LISTFEATUREGROUPREQUEST_LABELSENTRY._options = None
  _LISTFEATUREGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _FEATUREGROUPSERVICE.methods_by_name['ListFeatureGroups']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['ListFeatureGroups']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/featuregroups/{namespace}'
  _FEATUREGROUPSERVICE.methods_by_name['CreateFeatureGroup']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['CreateFeatureGroup']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/featuregroups:\001*'
  _FEATUREGROUPSERVICE.methods_by_name['GetFeatureGroup']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['GetFeatureGroup']._serialized_options = b'\202\323\344\223\002&\022$/v1/featuregroups/{namespace}/{name}'
  _FEATUREGROUPSERVICE.methods_by_name['UpdateFeatureGroup']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['UpdateFeatureGroup']._serialized_options = b'\202\323\344\223\002U\032P/v1/featuregroups/{featuregroup.metadata.namespace}/{featuregroup.metadata.name}:\001*'
  _FEATUREGROUPSERVICE.methods_by_name['DeleteFeatureGroup']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['DeleteFeatureGroup']._serialized_options = b'\202\323\344\223\002&*$/v1/featuregroups/{namespace}/{name}'
  _FEATUREGROUPSERVICE.methods_by_name['PauseFeatureGroup']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['PauseFeatureGroup']._serialized_options = b'\202\323\344\223\002,\"*/v1/featuregroups/{namespace}/{name}:pause'
  _FEATUREGROUPSERVICE.methods_by_name['ResumeFeatureGroup']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['ResumeFeatureGroup']._serialized_options = b'\202\323\344\223\002,\"*/v1/featuregroups/{namespace}/{name}:pause'
  _LISTFEATUREGROUPREQUEST._serialized_start=268
  _LISTFEATUREGROUPREQUEST._serialized_end=525
  _LISTFEATUREGROUPREQUEST_LABELSENTRY._serialized_start=480
  _LISTFEATUREGROUPREQUEST_LABELSENTRY._serialized_end=525
  _LISTFEATUREGROUPRESPONSE._serialized_start=528
  _LISTFEATUREGROUPRESPONSE._serialized_end=674
  _CREATEFEATUREGROUPREQUEST._serialized_start=676
  _CREATEFEATUREGROUPREQUEST._serialized_end=793
  _CREATEFEATUREGROUPRESPONSE._serialized_start=795
  _CREATEFEATUREGROUPRESPONSE._serialized_end=823
  _UPDATEFEATUREGROUPREQUEST._serialized_start=826
  _UPDATEFEATUREGROUPREQUEST._serialized_end=991
  _UPDATEFEATUREGROUPRESPONSE._serialized_start=993
  _UPDATEFEATUREGROUPRESPONSE._serialized_end=1021
  _GETFEATUREGROUPREQUEST._serialized_start=1023
  _GETFEATUREGROUPREQUEST._serialized_end=1080
  _GETFEATUREGROUPRESPONSE._serialized_start=1083
  _GETFEATUREGROUPRESPONSE._serialized_end=1212
  _DELETEFEATUREGROUPREQUEST._serialized_start=1214
  _DELETEFEATUREGROUPREQUEST._serialized_end=1274
  _DELETEFEATUREGROUPRESPONSE._serialized_start=1276
  _DELETEFEATUREGROUPRESPONSE._serialized_end=1304
  _PAUSEFEATUREGROUPRESPONSE._serialized_start=1306
  _PAUSEFEATUREGROUPRESPONSE._serialized_end=1333
  _PAUSEFEATUREGROUPREQUEST._serialized_start=1335
  _PAUSEFEATUREGROUPREQUEST._serialized_end=1394
  _RESUMEFEATUREGROUPRESPONSE._serialized_start=1396
  _RESUMEFEATUREGROUPRESPONSE._serialized_end=1424
  _RESUMEFEATUREGROUPREQUEST._serialized_start=1426
  _RESUMEFEATUREGROUPREQUEST._serialized_end=1486
  _FEATUREGROUPSERVICE._serialized_start=1489
  _FEATUREGROUPSERVICE._serialized_end=3181
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.modelclass.v1 import modelclass_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2


class ModelClassServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListModelClasses = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/ListModelClasses',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.ListModelClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.ListModelClassResponse.FromString,
                )
        self.CreateModelClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/CreateModelClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassResponse.FromString,
                )
        self.GetModelClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/GetModelClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.GetModelClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.GetModelClassResponse.FromString,
                )
        self.UpdateModelClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/UpdateModelClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.UpdateModelClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.UpdateModelClassResponse.FromString,
                )
        self.DeleteModelClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/DeleteModelClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.DeleteModelClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.DeleteModelClassResponse.FromString,
                )
        self.CreateModelClassProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/CreateModelClassProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassProfileResponse.FromString,
                )


class ModelClassServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListModelClasses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModelClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModelClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelClassProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelClassServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListModelClasses': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelClasses,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.ListModelClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.ListModelClassResponse.SerializeToString,
            ),
            'CreateModelClass': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassResponse.SerializeToString,
            ),
            'GetModelClass': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.GetModelClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.GetModelClassResponse.SerializeToString,
            ),
            'UpdateModelClass': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModelClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.UpdateModelClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.UpdateModelClassResponse.SerializeToString,
            ),
            'DeleteModelClass': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModelClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.DeleteModelClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.DeleteModelClassResponse.SerializeToString,
            ),
            'CreateModelClassProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelClassProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassProfileResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.study.v1.ModelClassService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelClassService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListModelClasses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/ListModelClasses',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.ListModelClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.ListModelClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/CreateModelClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/GetModelClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.GetModelClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.GetModelClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModelClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/UpdateModelClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.UpdateModelClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.UpdateModelClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModelClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/DeleteModelClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.DeleteModelClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.DeleteModelClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelClassProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/CreateModelClassProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.featuregroup.v1 import featuregroup_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2


class FeatureGroupServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListFeatureGroups = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/ListFeatureGroups',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ListFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ListFeatureGroupResponse.FromString,
                )
        self.CreateFeatureGroup = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/CreateFeatureGroup',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.CreateFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.CreateFeatureGroupResponse.FromString,
                )
        self.GetFeatureGroup = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/GetFeatureGroup',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.GetFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.GetFeatureGroupResponse.FromString,
                )
        self.UpdateFeatureGroup = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/UpdateFeatureGroup',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.UpdateFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.UpdateFeatureGroupResponse.FromString,
                )
        self.DeleteFeatureGroup = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/DeleteFeatureGroup',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.DeleteFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.DeleteFeatureGroupResponse.FromString,
                )
        self.PauseFeatureGroup = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/PauseFeatureGroup',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.PauseFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.PauseFeatureGroupResponse.FromString,
                )
        self.ResumeFeatureGroup = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/ResumeFeatureGroup',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ResumeFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ResumeFeatureGroupResponse.FromString,
                )


class FeatureGroupServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListFeatureGroups(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeatureGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseFeatureGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeFeatureGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureGroupServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListFeatureGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureGroups,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ListFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ListFeatureGroupResponse.SerializeToString,
            ),
            'CreateFeatureGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeatureGroup,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.CreateFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.CreateFeatureGroupResponse.SerializeToString,
            ),
            'GetFeatureGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureGroup,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.GetFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.GetFeatureGroupResponse.SerializeToString,
            ),
            'UpdateFeatureGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureGroup,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.UpdateFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.UpdateFeatureGroupResponse.SerializeToString,
            ),
            'DeleteFeatureGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureGroup,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.DeleteFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.DeleteFeatureGroupResponse.SerializeToString,
            ),
            'PauseFeatureGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseFeatureGroup,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.PauseFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.PauseFeatureGroupResponse.SerializeToString,
            ),
            'ResumeFeatureGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeFeatureGroup,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ResumeFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ResumeFeatureGroupResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureGroupService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListFeatureGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/ListFeatureGroups',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ListFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ListFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeatureGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/CreateFeatureGroup',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.CreateFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.CreateFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/GetFeatureGroup',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.GetFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.GetFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/UpdateFeatureGroup',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.UpdateFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.UpdateFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/DeleteFeatureGroup',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.DeleteFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.DeleteFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseFeatureGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/PauseFeatureGroup',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.PauseFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.PauseFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeFeatureGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/ResumeFeatureGroup',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ResumeFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ResumeFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.lab.v1 import lab_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2


class LabServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListLabs = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.lab.v1.LabService/ListLabs',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.ListLabsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.ListLabsResponse.FromString,
                )
        self.CreateLab = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.lab.v1.LabService/CreateLab',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.CreateLabRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.CreateLabResponse.FromString,
                )
        self.GetLab = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.lab.v1.LabService/GetLab',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.GetLabRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.GetLabResponse.FromString,
                )
        self.UpdateLab = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.lab.v1.LabService/UpdateLab',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.UpdateLabRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.UpdateLabResponse.FromString,
                )
        self.DeleteLab = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.lab.v1.LabService/DeleteLab',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.DeleteLabRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.DeleteLabResponse.FromString,
                )


class LabServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListLabs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateLab(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLab(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateLab(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteLab(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LabServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListLabs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLabs,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.ListLabsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.ListLabsResponse.SerializeToString,
            ),
            'CreateLab': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateLab,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.CreateLabRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.CreateLabResponse.SerializeToString,
            ),
            'GetLab': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLab,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.GetLabRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.GetLabResponse.SerializeToString,
            ),
            'UpdateLab': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateLab,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.UpdateLabRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.UpdateLabResponse.SerializeToString,
            ),
            'DeleteLab': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteLab,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.DeleteLabRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.DeleteLabResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.lab.v1.LabService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LabService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListLabs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.lab.v1.LabService/ListLabs',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.ListLabsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.ListLabsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateLab(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.lab.v1.LabService/CreateLab',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.CreateLabRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.CreateLabResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLab(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.lab.v1.LabService/GetLab',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.GetLabRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.GetLabResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateLab(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.lab.v1.LabService/UpdateLab',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.UpdateLabRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.UpdateLabResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteLab(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.lab.v1.LabService/DeleteLab',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.DeleteLabRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_lab_dot_v1_dot_lab__pb2.DeleteLabResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/apimachinery/pkg/runtime/schema/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6k8s.io/apimachinery/pkg/runtime/schema/generated.proto\x12&k8s.io.apimachinery.pkg.runtime.schemaB(Z&k8s.io/apimachinery/pkg/runtime/schema')



if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&k8s.io/apimachinery/pkg/runtime/schema'
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.attachment.v1 import attachment_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2


class AttachmentServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListAttachments = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService/ListAttachments',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.ListAttachmentsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.ListAttachmentsResponse.FromString,
                )
        self.CreateAttachment = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService/CreateAttachment',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.CreateAttachmentRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.CreateAttachmentResponse.FromString,
                )
        self.GetAttachment = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService/GetAttachment',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.GetAttachmentRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.GetAttachmentResponse.FromString,
                )
        self.UpdateAttachment = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService/UpdateAttachment',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.UpdateAttachmentRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.UpdateAttachmentResponse.FromString,
                )
        self.DeleteAttachment = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService/DeleteAttachment',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.DeleteAttachmentRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.DeleteAttachmentResponse.FromString,
                )


class AttachmentServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListAttachments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAttachment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAttachment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAttachment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAttachment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AttachmentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListAttachments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAttachments,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.ListAttachmentsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.ListAttachmentsResponse.SerializeToString,
            ),
            'CreateAttachment': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAttachment,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.CreateAttachmentRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.CreateAttachmentResponse.SerializeToString,
            ),
            'GetAttachment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAttachment,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.GetAttachmentRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.GetAttachmentResponse.SerializeToString,
            ),
            'UpdateAttachment': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAttachment,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.UpdateAttachmentRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.UpdateAttachmentResponse.SerializeToString,
            ),
            'DeleteAttachment': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAttachment,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.DeleteAttachmentRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.DeleteAttachmentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AttachmentService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListAttachments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService/ListAttachments',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.ListAttachmentsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.ListAttachmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAttachment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService/CreateAttachment',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.CreateAttachmentRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.CreateAttachmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAttachment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService/GetAttachment',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.GetAttachmentRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.GetAttachmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAttachment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService/UpdateAttachment',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.UpdateAttachmentRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.UpdateAttachmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAttachment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.attachment.v1.AttachmentService/DeleteAttachment',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.DeleteAttachmentRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_attachment_dot_v1_dot_attachment__pb2.DeleteAttachmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.dataset.v1 import dataset_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2


class DatasetServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDatasets = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/ListDatasets',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ListDatasetsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ListDatasetsResponse.FromString,
                )
        self.GetDataset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/GetDataset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatasetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatasetResponse.FromString,
                )
        self.CreateDataset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/CreateDataset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateDatasetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateDatasetResponse.FromString,
                )
        self.UpdateDataset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/UpdateDataset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.UpdateDatasetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.UpdateDatasetResponse.FromString,
                )
        self.DeleteDataset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/DeleteDataset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.DeleteDatasetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.DeleteDatasetResponse.FromString,
                )
        self.CompareDatasets = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/CompareDatasets',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CompareDatasetsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CompareDatasetsResponse.FromString,
                )
        self.GetDatasetProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/GetDatasetProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatasetProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatasetProfileResponse.FromString,
                )
        self.CreateDatasetProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/CreateDatasetProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateDatasetProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateDatasetProfileResponse.FromString,
                )
        self.CreateColumnProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/CreateColumnProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateColumnProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateColumnProfileResponse.FromString,
                )
        self.GenerateDataset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/GenerateDataset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GenerateDatasetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GenerateDatasetResponse.FromString,
                )
        self.ValidateDataset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/ValidateDataset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ValidateDatasetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ValidateDatasetResponse.FromString,
                )
        self.DownloadDataset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/DownloadDataset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.DownloadDatasetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.DownloadDatasetResponse.FromString,
                )
        self.GetDatabases = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/GetDatabases',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatabasesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatabasesResponse.FromString,
                )
        self.GetTables = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/GetTables',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetTablesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetTablesResponse.FromString,
                )
        self.ExecuteSql = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/ExecuteSql',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ExecuteSqlRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ExecuteSqlResponse.FromString,
                )
        self.GetAnomalies = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/GetAnomalies',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetAnomaliesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetAnomaliesResponse.FromString,
                )


class DatasetServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDatasets(self, request, context):
        """Datasets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompareDatasets(self, request, context):
        """compare one or more datasets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatasetProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDatasetProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateColumnProfile(self, request, context):
        """Get a single column viz, we do that since we want to parallelize the computation of the viz
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateDataset(self, request, context):
        """generate a syntatic dataset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateDataset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadDataset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatabases(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTables(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteSql(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAnomalies(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DatasetServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDatasets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDatasets,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ListDatasetsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ListDatasetsResponse.SerializeToString,
            ),
            'GetDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatasetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatasetResponse.SerializeToString,
            ),
            'CreateDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateDatasetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateDatasetResponse.SerializeToString,
            ),
            'UpdateDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.UpdateDatasetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.UpdateDatasetResponse.SerializeToString,
            ),
            'DeleteDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.DeleteDatasetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.DeleteDatasetResponse.SerializeToString,
            ),
            'CompareDatasets': grpc.unary_unary_rpc_method_handler(
                    servicer.CompareDatasets,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CompareDatasetsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CompareDatasetsResponse.SerializeToString,
            ),
            'GetDatasetProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatasetProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatasetProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatasetProfileResponse.SerializeToString,
            ),
            'CreateDatasetProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDatasetProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateDatasetProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateDatasetProfileResponse.SerializeToString,
            ),
            'CreateColumnProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateColumnProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateColumnProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateColumnProfileResponse.SerializeToString,
            ),
            'GenerateDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateDataset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GenerateDatasetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GenerateDatasetResponse.SerializeToString,
            ),
            'ValidateDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateDataset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ValidateDatasetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ValidateDatasetResponse.SerializeToString,
            ),
            'DownloadDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadDataset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.DownloadDatasetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.DownloadDatasetResponse.SerializeToString,
            ),
            'GetDatabases': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatabases,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatabasesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatabasesResponse.SerializeToString,
            ),
            'GetTables': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTables,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetTablesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetTablesResponse.SerializeToString,
            ),
            'ExecuteSql': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteSql,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ExecuteSqlRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ExecuteSqlResponse.SerializeToString,
            ),
            'GetAnomalies': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAnomalies,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetAnomaliesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetAnomaliesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.dataset.v1.DatasetService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DatasetService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDatasets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/ListDatasets',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ListDatasetsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ListDatasetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/GetDataset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatasetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/CreateDataset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateDatasetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/UpdateDataset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.UpdateDatasetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.UpdateDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/DeleteDataset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.DeleteDatasetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.DeleteDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompareDatasets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/CompareDatasets',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CompareDatasetsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CompareDatasetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDatasetProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/GetDatasetProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatasetProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatasetProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDatasetProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/CreateDatasetProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateDatasetProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateDatasetProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateColumnProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/CreateColumnProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateColumnProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.CreateColumnProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/GenerateDataset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GenerateDatasetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GenerateDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/ValidateDataset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ValidateDatasetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ValidateDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/DownloadDataset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.DownloadDatasetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.DownloadDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDatabases(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/GetDatabases',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatabasesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetDatabasesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTables(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/GetTables',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetTablesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetTablesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteSql(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/ExecuteSql',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ExecuteSqlRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.ExecuteSqlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAnomalies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataset.v1.DatasetService/GetAnomalies',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetAnomaliesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataset_dot_v1_dot_dataset__pb2.GetAnomaliesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/alert/v1/alert.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;github.com/metaprov/modelaapi/services/alert/v1/alert.proto\x12/github.com.metaprov.modelaapi.services.alert.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xee\x01\n\x11ListAlertsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12^\n\x06labels\x18\x02 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x7f\n\x12ListAlertsResponse\x12P\n\x06\x61lerts\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.AlertList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x0f\n\rAlertResponse\"a\n\x12\x43reateAlertRequest\x12K\n\x05\x61lert\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"\x15\n\x13\x43reateAlertResponse\"\x92\x01\n\x12UpdateAlertRequest\x12K\n\x05\x61lert\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x15\n\x13UpdateAlertResponse\"2\n\x0fGetAlertRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x10GetAlertResponse\x12K\n\x05\x61lert\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"<\n\x19GetAlertNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"q\n\x1aGetAlertNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"5\n\x12\x44\x65leteAlertRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteAlertResponse2\xd6\x07\n\x0c\x41lertService\x12\xb5\x01\n\nListAlerts\x12\x42.github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest\x1a\x43.github.com.metaprov.modelaapi.services.alert.v1.ListAlertsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/alerts/{namespace}\x12\xaf\x01\n\x0b\x43reateAlert\x12\x43.github.com.metaprov.modelaapi.services.alert.v1.CreateAlertRequest\x1a\x44.github.com.metaprov.modelaapi.services.alert.v1.CreateAlertResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/v1/alerts:\x01*\x12\xb6\x01\n\x08GetAlert\x12@.github.com.metaprov.modelaapi.services.alert.v1.GetAlertRequest\x1a\x41.github.com.metaprov.modelaapi.services.alert.v1.GetAlertResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/alerts/{namespace}/{name}\x12\xe0\x01\n\x0bUpdateAlert\x12\x43.github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertRequest\x1a\x44.github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertResponse\"F\x82\xd3\xe4\x93\x02@\x1a;/v1/alerts/{alert.metadata.namespace}/{alert.metadata.name}:\x01*\x12\xbf\x01\n\x0b\x44\x65leteAlert\x12\x43.github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertRequest\x1a\x44.github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertResponse\"%\x82\xd3\xe4\x93\x02\x1f*\x1d/v1/alerts/{namespace}/{name}B1Z/github.com/metaprov/modelaapi/services/alert/v1b\x06proto3')



_LISTALERTSREQUEST = DESCRIPTOR.message_types_by_name['ListAlertsRequest']
_LISTALERTSREQUEST_LABELSENTRY = _LISTALERTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTALERTSRESPONSE = DESCRIPTOR.message_types_by_name['ListAlertsResponse']
_ALERTRESPONSE = DESCRIPTOR.message_types_by_name['AlertResponse']
_CREATEALERTREQUEST = DESCRIPTOR.message_types_by_name['CreateAlertRequest']
_CREATEALERTRESPONSE = DESCRIPTOR.message_types_by_name['CreateAlertResponse']
_UPDATEALERTREQUEST = DESCRIPTOR.message_types_by_name['UpdateAlertRequest']
_UPDATEALERTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateAlertResponse']
_GETALERTREQUEST = DESCRIPTOR.message_types_by_name['GetAlertRequest']
_GETALERTRESPONSE = DESCRIPTOR.message_types_by_name['GetAlertResponse']
_GETALERTNAMESPACESREQUEST = DESCRIPTOR.message_types_by_name['GetAlertNamespacesRequest']
_GETALERTNAMESPACESRESPONSE = DESCRIPTOR.message_types_by_name['GetAlertNamespacesResponse']
_DELETEALERTREQUEST = DESCRIPTOR.message_types_by_name['DeleteAlertRequest']
_DELETEALERTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteAlertResponse']
ListAlertsRequest = _reflection.GeneratedProtocolMessageType('ListAlertsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTALERTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTALERTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest)
  })
_sym_db.RegisterMessage(ListAlertsRequest)
_sym_db.RegisterMessage(ListAlertsRequest.LabelsEntry)

ListAlertsResponse = _reflection.GeneratedProtocolMessageType('ListAlertsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ListAlertsResponse)
  })
_sym_db.RegisterMessage(ListAlertsResponse)

AlertResponse = _reflection.GeneratedProtocolMessageType('AlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.AlertResponse)
  })
_sym_db.RegisterMessage(AlertResponse)

CreateAlertRequest = _reflection.GeneratedProtocolMessageType('CreateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.CreateAlertRequest)
  })
_sym_db.RegisterMessage(CreateAlertRequest)

CreateAlertResponse = _reflection.GeneratedProtocolMessageType('CreateAlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.CreateAlertResponse)
  })
_sym_db.RegisterMessage(CreateAlertResponse)

UpdateAlertRequest = _reflection.GeneratedProtocolMessageType('UpdateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertRequest)
  })
_sym_db.RegisterMessage(UpdateAlertRequest)

UpdateAlertResponse = _reflection.GeneratedProtocolMessageType('UpdateAlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertResponse)
  })
_sym_db.RegisterMessage(UpdateAlertResponse)

GetAlertRequest = _reflection.GeneratedProtocolMessageType('GetAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.GetAlertRequest)
  })
_sym_db.RegisterMessage(GetAlertRequest)

GetAlertResponse = _reflection.GeneratedProtocolMessageType('GetAlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.GetAlertResponse)
  })
_sym_db.RegisterMessage(GetAlertResponse)

GetAlertNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetAlertNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.GetAlertNamespacesRequest)
  })
_sym_db.RegisterMessage(GetAlertNamespacesRequest)

GetAlertNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetAlertNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.GetAlertNamespacesResponse)
  })
_sym_db.RegisterMessage(GetAlertNamespacesResponse)

DeleteAlertRequest = _reflection.GeneratedProtocolMessageType('DeleteAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertRequest)
  })
_sym_db.RegisterMessage(DeleteAlertRequest)

DeleteAlertResponse = _reflection.GeneratedProtocolMessageType('DeleteAlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertResponse)
  })
_sym_db.RegisterMessage(DeleteAlertResponse)

_ALERTSERVICE = DESCRIPTOR.services_by_name['AlertService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/metaprov/modelaapi/services/alert/v1'
  _LISTALERTSREQUEST_LABELSENTRY._options = None
  _LISTALERTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _ALERTSERVICE.methods_by_name['ListAlerts']._options = None
  _ALERTSERVICE.methods_by_name['ListAlerts']._serialized_options = b'\202\323\344\223\002\030\022\026/v1/alerts/{namespace}'
  _ALERTSERVICE.methods_by_name['CreateAlert']._options = None
  _ALERTSERVICE.methods_by_name['CreateAlert']._serialized_options = b'\202\323\344\223\002\017\"\n/v1/alerts:\001*'
  _ALERTSERVICE.methods_by_name['GetAlert']._options = None
  _ALERTSERVICE.methods_by_name['GetAlert']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/alerts/{namespace}/{name}'
  _ALERTSERVICE.methods_by_name['UpdateAlert']._options = None
  _ALERTSERVICE.methods_by_name['UpdateAlert']._serialized_options = b'\202\323\344\223\002@\032;/v1/alerts/{alert.metadata.namespace}/{alert.metadata.name}:\001*'
  _ALERTSERVICE.methods_by_name['DeleteAlert']._options = None
  _ALERTSERVICE.methods_by_name['DeleteAlert']._serialized_options = b'\202\323\344\223\002\037*\035/v1/alerts/{namespace}/{name}'
  _LISTALERTSREQUEST._serialized_start=311
  _LISTALERTSREQUEST._serialized_end=549
  _LISTALERTSREQUEST_LABELSENTRY._serialized_start=504
  _LISTALERTSREQUEST_LABELSENTRY._serialized_end=549
  _LISTALERTSRESPONSE._serialized_start=551
  _LISTALERTSRESPONSE._serialized_end=678
  _ALERTRESPONSE._serialized_start=680
  _ALERTRESPONSE._serialized_end=695
  _CREATEALERTREQUEST._serialized_start=697
  _CREATEALERTREQUEST._serialized_end=794
  _CREATEALERTRESPONSE._serialized_start=796
  _CREATEALERTRESPONSE._serialized_end=817
  _UPDATEALERTREQUEST._serialized_start=820
  _UPDATEALERTREQUEST._serialized_end=966
  _UPDATEALERTRESPONSE._serialized_start=968
  _UPDATEALERTRESPONSE._serialized_end=989
  _GETALERTREQUEST._serialized_start=991
  _GETALERTREQUEST._serialized_end=1041
  _GETALERTRESPONSE._serialized_start=1043
  _GETALERTRESPONSE._serialized_end=1152
  _GETALERTNAMESPACESREQUEST._serialized_start=1154
  _GETALERTNAMESPACESREQUEST._serialized_end=1214
  _GETALERTNAMESPACESRESPONSE._serialized_start=1216
  _GETALERTNAMESPACESRESPONSE._serialized_end=1329
  _DELETEALERTREQUEST._serialized_start=1331
  _DELETEALERTREQUEST._serialized_end=1384
  _DELETEALERTRESPONSE._serialized_start=1386
  _DELETEALERTRESPONSE._serialized_end=1407
  _ALERTSERVICE._serialized_start=1410
  _ALERTSERVICE._serialized_end=2392
# @@protoc_insertion_point(module_scope)
